@@ -1,5 +1,5 @@
-//  
-//  NetBSD port:  
+//
+//  NetBSD port:
 //  Copyright (c) 1995,1996,1997 Brian Grayson(bgrayson@netbsd.org)
 //
 //  This file was written by Brian Grayson for the NetBSD and xosview
@@ -15,23 +15,27 @@
 #define _DISKMETER_H_
 
 #include "fieldmetergraph.h"
-#include <sys/types.h>		//  For u_int64_t
+#include "defines.h"
+
 
 class DiskMeter : public FieldMeterGraph {
 public:
-  DiskMeter( XOSView *parent, float max );
-  ~DiskMeter( void );
+	DiskMeter( XOSView *parent, double max );
+	~DiskMeter( void );
 
-  const char *name( void ) const { return "DiskMeter"; }
-  void checkevent( void );
+	const char *name( void ) const { return "DiskMeter"; }
+	void checkevent( void );
+	void checkResources( void );
 
-  void checkResources( void );
 protected:
-  void getstats( void );
+	void getstats( void );
+
 private:
-  u_int64_t prevBytes;
-  int kernelHasStats_;
-  float	maxBandwidth_;
+#ifndef HAVE_DEVSTAT
+	u_int64_t prevreads_, prevwrites_;
+#endif
+	double maxBandwidth_;
 };
 
+
 #endif
