@@ -86,8 +86,11 @@ void IntMeter::updateirqcount( bool init ) {
 			if ( &*it == &*realintnum_.rbegin() ) { // last element
 				if (it->first == prev + 1)
 					os << "-" ;
-				else
+				else {
+					if (prev == prev2 + 1)
+						os << "-" << prev;
 					os << "," ;
+				}
 				os << it->first;
 			}
 			else {
