@@ -1,4 +1,4 @@
-//  
+//
 //  Copyright (c) 1999 by Brian Grayson (bgrayson@netbsd.org)
 //
 //  This file may be distributed under terms of the GPL or of the BSD
@@ -12,23 +12,24 @@
 #define _IRQRATEMETER_H_
 
 #include "fieldmetergraph.h"
-#include "kernel.h"
+
 
 class IrqRateMeter : public FieldMeterGraph {
 public:
-  IrqRateMeter( XOSView *parent );
-  ~IrqRateMeter( void );
+	IrqRateMeter( XOSView *parent );
+	~IrqRateMeter( void );
 
-  const char *name( void ) const { return "IrqRateMeter"; }  
-  void checkevent( void );
+	const char *name( void ) const { return "IrqRateMeter"; }
+	void checkevent( void );
+	void checkResources( void );
+
+private:
+	unsigned long *irqs_, *lastirqs_;
+	unsigned int irqcount_;
 
-  void checkResources( void );
 protected:
-  unsigned long irqs_[NUM_INTR], lastirqs_[NUM_INTR];
-  unsigned long delta;
-
-  void getinfo( void );
-  unsigned long oncol_, idlecol_;
-  bool kernelHasStats_;
+	void getinfo( void );
 };
+
+
 #endif
