@@ -1,4 +1,4 @@
-//  
+//
 //  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
 //  Copyright (c) 1995, 1996, 1997-2002 by Brian Grayson (bgrayson@netbsd.org)
 //
@@ -21,19 +21,21 @@
 
 class LoadMeter : public FieldMeterGraph {
 public:
-  LoadMeter( XOSView *parent );
-  ~LoadMeter( void );
+	LoadMeter( XOSView *parent );
+	~LoadMeter( void );
 
-  const char *name( void ) const { return "LoadMeter"; }  
-  void checkevent( void );
+	const char *name( void ) const { return "LoadMeter"; }
+	void checkevent( void );
+	void checkResources( void );
 
-  void checkResources( void );
 protected:
+	void getloadinfo( void );
 
-  void getloadinfo( void );
-  unsigned long procloadcol_, warnloadcol_, critloadcol_;
 private:
-  int warnThreshold, critThreshold, alarmstate, lastalarmstate;
+	unsigned long procloadcol_, warnloadcol_, critloadcol_;
+	int warnThreshold_, critThreshold_, alarmstate_, lastalarmstate_;
+	int old_cpu_speed_, cur_cpu_speed_;
+	bool do_cpu_speed_;
 };
 
 
