@@ -1,7 +1,7 @@
-//  
+//
 //  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
 //
-//  NetBSD port:  
+//  NetBSD port:
 //  Copyright (c) 1995, 1996, 1997-2002 by Brian Grayson (bgrayson@netbsd.org)
 //
 //  This file was written by Brian Grayson for the NetBSD and xosview
@@ -17,34 +17,27 @@
 #define _NETMETER_H_
 
 #include "fieldmetergraph.h"
-#include "timer.h"
+#include <string>
 
-class Host;
 
 class NetMeter : public FieldMeterGraph {
 public:
-  NetMeter(XOSView *parent, float max);
-  ~NetMeter( void );
+	NetMeter( XOSView *parent, float max );
+	~NetMeter( void );
 
-  const char *name( void ) const { return "NetMeter"; }  
-  void checkevent( void );
+	const char *name( void ) const { return "NetMeter"; }
+	void checkevent( void );
+	void checkResources( void );
 
-  void checkResources( void );
-
-  void BSDGetNetInOut (long long * inbytes, long long * outbytes);
 protected:
-  float netBandwidth_;
-  std::string netIface_;
+	void getstats(void);
 
 private:
-  //  NetBSD:  Use long long, so we won't run into problems after 4 GB
-  //  has been transferred over the net!
-  long long _lastBytesIn, _lastBytesOut;
-
-  //  Did the meter initialize properly?
-  bool kernelHasStats_;
-
-  void adjust(void);
+	unsigned long long lastBytesIn_, lastBytesOut_;
+	float netBandwidth_;
+	std::string netIface_;
+	bool ignored_;
 };
 
+
 #endif
