@@ -13,6 +13,7 @@
 #include <string>
 #include <sstream>
 #include <ctype.h>
+#include <sys/utsname.h>
 
 static const char STATFILENAME[] = "/proc/stat";
 static const char VERSIONFILENAME[] = "/proc/sys/kernel/osrelease";
@@ -337,17 +338,11 @@ const char *CPUMeter::toUpper(const char *str){
 }
 
 int CPUMeter::getkernelversion(void){
-  std::ifstream f(VERSIONFILENAME);
-  if (!f) {
-    std::cerr << "Can not get kernel version from " << VERSIONFILENAME << "." << std::endl;
-    exit(1);
+  static int major = 0, minor = 0, micro = 0;
+  if (!major) {
+    struct utsname myosrelease;
+    uname(&myosrelease);
+    sscanf(myosrelease.release, "%d.%d.%d", &major, &minor, &micro);
   }
-
-  std::string version;
-  int major = 0, minor = 0, micro = 0;
-
-  f >> version;
-  sscanf(version.c_str(), "%d.%d.%d", &major, &minor, &micro);
-
-  return ( major*1000000 + minor*1000 + micro);
+  return (major*1000000 + minor*1000 + micro);
 }
