@@ -11,9 +11,7 @@
 #include "xosview.h"
 #include "cpumeter.h"
 #include <fstream>
-#include <sstream>
 #include <stdlib.h>
-#include <math.h>
 
 static const char LOADFILENAME[] = "/proc/loadavg";
 static const char SPEEDFILENAME[] = "/proc/cpuinfo";
@@ -78,15 +76,14 @@ void LoadMeter::checkResources( void ){
 void LoadMeter::checkevent( void ){
   getloadinfo();
   if ( do_cpu_speed ) {
-         getspeedinfo();
-         if ( old_cpu_speed_ != cur_cpu_speed_ ) {
-        // update the legend:
-        std::ostringstream legnd;
-        XOSDEBUG("SPEED: %d\n",cur_cpu_speed_);
-        legnd << "PROCS/MIN" << " " << cur_cpu_speed_ << " MHz"<< std::ends;
-            legend( legnd.str().c_str() );
-	drawlegend();
-     }
+    getspeedinfo();
+    if ( old_cpu_speed_ != cur_cpu_speed_ ) {
+      // update the legend:
+      char l[32];
+      snprintf(l, 32, "PROCS/MIN %d MHz", cur_cpu_speed_);
+      legend(l);
+      drawlegend();
+    }
   }
 
   drawfields();
@@ -120,14 +117,12 @@ void LoadMeter::getloadinfo( void ){
     lastalarmstate = alarmstate;
   }
 
-  if ( fields_[0]*5.0<total_ )
-    total_ = fields_[0];
-  else
-  if ( fields_[0]>total_ )
-    total_ = fields_[0]*5.0;
-
-  if ( total_ < 1.0)
-    total_ = 1.0;
+  // Adjust total to next power-of-two of the current load.
+  if ( (fields_[0]*5.0 < total_ && total_ > 1.0) || fields_[0] > total_ ) {
+    unsigned int i = fields_[0];
+    i |= i >> 1; i |= i >> 2; i |= i >> 4; i |= i >> 8; i |= i >> 16;  // i = 2^n - 1
+    total_ = i + 1;
+  }
 
   fields_[1] = (float) (total_ - fields_[0]);
 
