@@ -1,6 +1,6 @@
-//  
-//  Copyright (c) 1999 Thomas Waldmann ( ThomasWaldmann@gmx.de )
-//  based on work of Mike Romberg ( romberg@fsl.noaa.gov )
+//
+//  Copyright (c) 1999, 2006 Thomas Waldmann ( ThomasWaldmann@gmx.de )
+//  based on work of Mike Romberg ( mike.romberg@noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
@@ -21,7 +21,7 @@ public:
   void checkResources( void );
 
   static int countRAIDs( void );
-  
+
 protected:
 
   int _raiddev;
@@ -32,14 +32,14 @@ protected:
        working_map[20],
        resync_state[20];
   int  disknum;
-  
+
   unsigned long doneColor_, todoColor_, completeColor_;
-    
-  int find1(char *key, char *findwhat, int num1);
-  int find2(char *key, char *findwhat, int num1, int num2);
+
+  int find1(const char *key, const char *findwhat, int num1);
+  int find2(const char *key, const char *findwhat, int num1, int num2);
 
   int raidparse(char *cp);
-    
+
   void getRAIDstate( void );
 };
 
