@@ -1,14 +1,16 @@
-//  
-//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
+//
+//  Copyright (c) 1994, 1995, 2006 by Mike Romberg ( mike.romberg@noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
-//
-// $Id$
-//
+
 #ifndef _SERIALMETER_H_
 #define _SERIALMETER_H_
 
+// hack for not having linux/serial_reg.h, (Debian bug #427599)
+#define UART_LSR        5
+#define UART_MSR        6
+
 #include "bitmeter.h"
 
 class SerialMeter : public BitMeter {
@@ -22,7 +24,7 @@ public:
   static const char *getResourceName(Device dev);
 
   void checkevent( void );
-  
+
   void checkResources( void );
 
 private:
