@@ -1,4 +1,4 @@
-//  
+//
 //  Copyright (c) 1997 by Mike Romberg ( romberg@fsl.noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
@@ -9,13 +9,15 @@
 #ifndef _WIRELESSMETER_H_
 #define _WIRELESSMETER_H_
 
-
 #include "fieldmetergraph.h"
+#include <string>
+
+static const char WLFILENAME[] = "/proc/net/wireless";
 
 
 class WirelessMeter : public FieldMeterGraph {
 public:
-  WirelessMeter( XOSView *parent, int ID = 1, const char *wlID = "WL");
+  WirelessMeter( XOSView *parent, int ID = 0, const char *wlID = "WL");
   ~WirelessMeter( void );
 
   const char *name( void ) const { return "WirelessMeter"; }
@@ -24,12 +26,16 @@ public:
   void checkResources( void );
   static int countdevices(void);
   static const char *wirelessStr(int num);
-  char devname[256];
+
 protected:
   void getpwrinfo( void );
-  unsigned long poorqualcol_, fairqualcol_, goodqualcol_;
+
 private:
-  int alarmThreshold, qualitystate, lastqualitystate, _number;
+  unsigned long _poorqualcol, _fairqualcol, _goodqualcol;
+  int _lastquality, _number;
+  std::string _devname;
+
 };
 
+
 #endif
