@@ -1,4 +1,5 @@
 #include <X11/Xatom.h>
+#include <X11/xpm.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -78,6 +79,7 @@ XWin::~XWin( void ){
 void XWin::init( int argc, char **argv ){
   XGCValues            gcv;
   XSetWindowAttributes xswa;
+  Pixmap background_pixmap;
 
   setFont();
   setColors();
@@ -107,6 +109,10 @@ void XWin::init( int argc, char **argv ){
   XChangeWindowAttributes(display_, window_,
 			  (CWColormap | CWBitGravity), &xswa);
 
+  // If there is a pixmap file, set it as the background
+  if (getPixmap(&background_pixmap))
+    XSetWindowBackgroundPixmap(display_,window_,background_pixmap);
+
   // add the events
   Event *tmp = events_;
   while ( tmp != NULL ){
@@ -217,6 +223,35 @@ void XWin::setColors( void ){
 }
 //-----------------------------------------------------------------------------
 
+int XWin::getPixmap(Pixmap *pixmap)
+{
+  char	*pixmap_file;
+  XWindowAttributes	root_att;
+  XpmAttributes		pixmap_att;
+
+  pixmap_file = (char*) getResourceOrUseDefault("pixmapName",NULL);
+
+  if (!pixmap_file)
+    return 0;
+
+  XGetWindowAttributes(display_, DefaultRootWindow(display_),&root_att);
+  pixmap_att.closeness=30000;
+  pixmap_att.colormap=root_att.colormap;
+  pixmap_att.valuemask=XpmSize|XpmReturnPixels|XpmColormap|XpmCloseness;
+
+  if (XpmReadFileToPixmap(display_,DefaultRootWindow(display_),pixmap_file,
+      pixmap, NULL, &pixmap_att))
+  {
+    std::cerr << "Pixmap " << pixmap_file  << " not found" << std::endl;
+    std::cerr << "Defaulting to blank" << std::endl;
+    pixmap = NULL;
+    return 0;
+  }
+
+  return 1;
+}
+
+//-----------------------------------------------------------------------------
 void XWin::getGeometry( void ){
   char                 default_geometry[80];
   int                  bitmask;
